=========
Education
=========

Shopyo makes use of a number of packages, this
section points to some key resources to get you started

Shopyo specific
---------------

* Article: `Shopyo: Enhance Your Flask by Exploring An Advanced Flask App <https://dev.to/abdurrahmaanj/shopyo-enhance-your-flask-by-exploring-an-advanced-flask-app-40j3>`_
* Talk: `EuroPython - Django Clone From Scratch With Flask <https://youtu.be/rkzXQOC1T0Q>`_